Module schemas

Module schemas 

Schema Validation

Schema Validation Support (XSD)

This module exposes wraps xmlschemas in libxml2. See original documentation or look at the example at examples/schema_example.rs for usage.

WARNING: This module has not been tested in a multithreaded or multiprocessing environment.

Structs

SchemaParserContext
Wrapper on xmlSchemaParserCtxt
SchemaValidationContext
Wrapper on xmlSchemaValidCtxt